==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/nativequeries/cats/SodaCatPredicate.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using com.db4o;

namespace com.db4o.test.nativequeries.cats
{
	public abstract class SodaCatPredicate : com.db4o.query.Predicate
	{
		private int _count;

		public virtual void sodaQuery(ObjectContainer oc)
		{
			com.db4o.query.Query q = oc.query();
			q.constrain(typeof(Cat));
			constrain(q);
			q.execute();
		}

		public abstract void constrain(com.db4o.query.Query q);

#if NET_2_0
        public abstract void delegateNQ(ObjectContainer oc);
#endif

		public virtual void setCount(int count)
		{
			_count = count;
		}

		public virtual int lower()
		{
			return _count / 2 - 1;
		}

		public virtual int upper()
		{
			return _count / 2 + 1;
		}

	}
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/nativequeries/cats/SodaCatPredicate.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using com.db4o;

namespace com.db4o.test.nativequeries.cats
{
	public abstract class SodaCatPredicate : com.db4o.query.Predicate
	{
		private int _count;

		public virtual void SodaQuery(ObjectContainer oc)
		{
			com.db4o.query.Query q = oc.Query();
			q.Constrain(typeof(Cat));
			Constrain(q);
			q.Execute();
		}

		public abstract void Constrain(com.db4o.query.Query q);

#if NET_2_0
        public abstract void DelegateNQ(ObjectContainer oc);
#endif

		public virtual void SetCount(int count)
		{
			_count = count;
		}

		public virtual int Lower()
		{
			return _count / 2 - 1;
		}

		public virtual int Upper()
		{
			return _count / 2 + 1;
		}

	}
}
